@@ -5,21 +5,17 @@ from __future__ import absolute_import, division, print_function
 import os
 import sys
 
+import pytest
+from qtpy import QtWidgets
 import numpy as np
 from mock import patch, MagicMock
 
-try:
-    from IPython import __version__ as ipy_version
-except:
-    ipy_version = '0.0'
-
 from qtpy import QtCore
 from glue.core.data import Data
 from glue.core.component_link import ComponentLink
 from glue.core.data_collection import DataCollection
 from glue.core.tests.test_state import Cloner, containers_equal, doubler, clone
 from glue.tests.helpers import requires_ipython
-from glue.utils.qt import process_dialog
 from glue.viewers.image.qt import ImageViewer
 from glue.viewers.scatter.qt import ScatterViewer
 from glue.viewers.histogram.qt import HistogramViewer
@@ -43,6 +39,7 @@ class TestGlueApplication(object):
 
     def teardown_method(self, method):
         self.app.close()
+        self.app = None
 
     def test_new_tabs(self):
         t0 = tab_count(self.app)
@@ -134,27 +131,30 @@ class TestGlueApplication(object):
             assert len(self.app.current_tab.subWindowList()) == ct
 
     def test_new_data_viewer(self):
+
         with patch('glue.app.qt.application.pick_class') as pc:
 
             pc.return_value = ScatterViewer
 
             ct = len(self.app.current_tab.subWindowList())
 
-            self.app.choose_new_data_viewer()
+            viewer = self.app.choose_new_data_viewer()
             assert len(self.app.current_tab.subWindowList()) == ct + 1
+            viewer.close()
 
     def test_move(self):
         viewer = self.app.new_data_viewer(ScatterViewer)
         viewer.move(10, 20)
         assert viewer.position == (10, 20)
+        viewer.close()
 
     def test_resize(self):
         viewer = self.app.new_data_viewer(ScatterViewer)
         viewer.viewer_size = (100, 200)
         assert viewer.viewer_size == (100, 200)
+        viewer.close()
 
     def test_new_data_defaults(self):
-        from glue.config import qt_client
 
         with patch('glue.app.qt.application.pick_class') as pc:
             pc.return_value = None
@@ -171,14 +171,49 @@ class TestGlueApplication(object):
             assert kwargs['default'] is ImageViewer
 
     def test_drop_load_data(self):
+
+        load_data = MagicMock()
+        load_session = MagicMock()
+        self.app.load_data = load_data
+        self.app.restore_session_and_close = load_session
+
+        e = MagicMock()
+
         m = QtCore.QMimeData()
         m.setUrls([QtCore.QUrl('test.fits')])
-        e = MagicMock()
         e.mimeData.return_value = m
-        load = MagicMock()
-        self.app.load_data = load
+
         self.app.dropEvent(e)
-        assert load.call_count == 1
+        assert load_data.called_once_with('test.fits')
+        assert load_session.call_count == 0
+
+        load_data.reset_mock()
+
+        m = QtCore.QMimeData()
+        m.setUrls([QtCore.QUrl('test1.fits'), QtCore.QUrl('test2.fits')])
+        e.mimeData.return_value = m
+        self.app.dropEvent(e)
+        assert load_data.called_once_with(['test1.fits', 'test2.fits'])
+        assert load_session.call_count == 0
+
+        load_data.reset_mock()
+
+        m = QtCore.QMimeData()
+        m.setUrls([QtCore.QUrl('test.glu')])
+        e.mimeData.return_value = m
+        self.app.dropEvent(e)
+        assert load_data.call_count == 0
+        assert load_session.called_once_with(['test.glu'])
+
+        load_data.reset_mock()
+
+        m = QtCore.QMimeData()
+        m.setUrls([QtCore.QUrl('test.glu'), QtCore.QUrl('test.fits')])
+        e.mimeData.return_value = m
+        with patch('qtpy.QtWidgets.QMessageBox') as mb:
+            self.app.dropEvent(e)
+            assert mb.call_count == 1
+            assert "When dragging and dropping files" in mb.call_args[0][2]
 
     def test_subset_facet(self):
         # regression test for 335
@@ -298,17 +333,21 @@ class TestApplicationSession(object):
         dc = DataCollection([d])
         app = GlueApplication(dc)
         w = app.new_data_viewer(ScatterViewer, data=d)
-        self.check_clone(app)
+        copy1 = self.check_clone(app)
 
-        s1 = dc.new_subset_group()
-        s2 = dc.new_subset_group()
+        dc.new_subset_group()
+        dc.new_subset_group()
         assert len(w.layers) == 3
         l1, l2, l3 = w.layers
         l1.zorder, l2.zorder = l2.zorder, l1.zorder
         l3.visible = False
         assert l3.visible is False
-        copy = self.check_clone(app)
-        assert copy.viewers[0][0].layers[-1].visible is False
+        copy2 = self.check_clone(app)
+        assert copy2.viewers[0][0].layers[-1].visible is False
+
+        app.close()
+        copy1.close()
+        copy2.close()
 
     def test_multi_tab(self):
         d = Data(label='hist', x=[[1, 2], [2, 3]])
@@ -320,7 +359,10 @@ class TestApplicationSession(object):
         w2 = app.new_data_viewer(HistogramViewer, data=d)
         assert app.viewers == ((w1,), (w2,))
 
-        self.check_clone(app)
+        copy = self.check_clone(app)
+
+        app.close()
+        copy.close()
 
     def test_histogram(self):
         d = Data(label='hist', x=[[1, 2], [2, 3]])
@@ -328,14 +370,19 @@ class TestApplicationSession(object):
 
         app = GlueApplication(dc)
         w = app.new_data_viewer(HistogramViewer, data=d)
-        self.check_clone(app)
+        copy1 = self.check_clone(app)
 
         dc.new_subset_group()
         assert len(w.layers) == 2
-        self.check_clone(app)
+        copy2 = self.check_clone(app)
 
         w.nbins = 7
-        self.check_clone(app)
+        copy3 = self.check_clone(app)
+
+        app.close()
+        copy1.close()
+        copy2.close()
+        copy3.close()
 
     def test_subset_groups_remain_synced_after_restore(self):
         # regrssion test for 352
@@ -374,6 +421,9 @@ def test_reset_session_terminal():
 
     assert app2.has_terminal()
 
+    app.close()
+    app2.close()
+
 
 def test_open_session_terminal(tmpdir):
 
@@ -388,3 +438,6 @@ def test_open_session_terminal(tmpdir):
     app2 = app.restore_session(session_file)
 
     assert app2.has_terminal()
+
+    app.close()
+    app2.close()
