@@ -213,6 +213,12 @@ class LayerArtistEnabledMessage(Message):
         self.layer_artist = self.sender
 
 
+class LayerArtistUpdatedMessage(Message):
+    def __init__(self, sender, tag=None):
+        super(LayerArtistUpdatedMessage, self).__init__(sender, tag=tag)
+        self.layer_artist = self.sender
+
+
 class LayerArtistDisabledMessage(Message):
     def __init__(self, sender, tag=None):
         super(LayerArtistDisabledMessage, self).__init__(sender, tag=tag)
