@@ -85,7 +85,7 @@ from glue.core.subset_group import coerce_subset_groups
 from glue.utils import lookup_class
 
 
-literals = tuple([type(None), float, int, bytes, bool, list, tuple])
+literals = tuple([type(None), float, int, bytes, bool])
 
 if six.PY2:
     literals += (long,)
@@ -93,7 +93,9 @@ if six.PY2:
 
 literals += np.ScalarType
 
+builtin_iterables = (tuple, list, set)
 
+JSON_ENCODER = json.JSONEncoder()
 
 # We need to make sure that we don't break backward-compatibility when we move
 # classes/functions around in Glue, so we have a file that maps the old paths to
@@ -220,6 +222,25 @@ class VersionedDict(object):
         self._data[item][version] = value
 
 
+def as_nested_lists(obj):
+    items = []
+    for item in obj:
+        if type(item) in builtin_iterables:
+            item = as_nested_lists(item)
+        items.append(item)
+    return items
+
+
+def flattened(obj):
+    items = []
+    for item in obj:
+        if type(item) in builtin_iterables:
+            items += as_nested_lists(item)
+        else:
+            items.append(item)
+    return items
+
+
 class GlueSerializer(object):
 
     """
@@ -261,6 +282,12 @@ class GlueSerializer(object):
         if type(obj) in literals:
             return obj
 
+        # Now check for list, set, and tuple, and skip if they don't contain
+        # any non-literals.
+        if type(obj) in builtin_iterables:
+            if all(isinstance(x, literals) for x in flattened(obj)):
+                return as_nested_lists(obj)
+
         oid = id(obj)
 
         if oid in self._names:
@@ -299,6 +326,12 @@ class GlueSerializer(object):
         if type(obj) in literals:
             return obj
 
+        # Now check for list, set, and tuple, and skip if they don't contain
+        # any non-literals
+        if type(obj) in builtin_iterables:
+            if all(isinstance(x, literals) for x in flattened(obj)):
+                return as_nested_lists(obj)
+
         oid = id(obj)
         if oid in self._working:
             raise GlueSerializeError("Circular reference detected")
@@ -322,6 +355,7 @@ class GlueSerializer(object):
         return result
 
     def _dispatch(self, obj):
+
         if hasattr(obj, '__gluestate__'):
             return type(obj).__gluestate__, 1
 
@@ -365,9 +399,12 @@ class GlueSerializer(object):
         """
         if np.isscalar(o) and isinstance(o, np.generic):
             return np.asscalar(o)  # coerce numpy number to pure-python type
-        if isinstance(o, (tuple, set)):
+        elif isinstance(o, (tuple, set)):
             return list(o)
-        return o
+        else:
+            # Dispatch to JSONEncoder so that we see errors straight away
+            # if an object can't be serialized.
+            return JSON_ENCODER.default(o)
 
     def dumps(self, indent=None):
         result = self.dumpo()
@@ -449,7 +486,7 @@ class GlueUnSerializer(object):
             self._working.add(obj_id)
             rec = self._rec[obj_id]
 
-        elif isinstance(obj_id, literals):
+        elif isinstance(obj_id, literals) or isinstance(obj_id, (tuple, list)):
             return obj_id
         else:
             rec = obj_id
@@ -490,6 +527,46 @@ def _load_dict(rec, context):
                 for key, value in rec['contents'].items())
 
 
+@saver(tuple)
+def _save_tuple(state, context):
+    return dict(contents=[context.do(item) for item in state])
+
+
+@loader(tuple)
+def _load_tuple(rec, context):
+    return tuple(_load_list(rec, context))
+
+
+@saver(list)
+def _save_list(state, context):
+    return dict(contents=[context.do(item) for item in state])
+
+
+@loader(list)
+def _load_list(rec, context):
+    return [context.object(item) for item in rec['contents']]
+
+
+@saver(set)
+def _save_set(state, context):
+    return dict(contents=[context.do(item) for item in state])
+
+
+@loader(set)
+def _load_set(rec, context):
+    return set(_load_list(rec, context))
+
+
+@saver(slice)
+def _save_slice(slc, context):
+    return dict(start=slc.start, stop=slc.stop, step=slc.step)
+
+
+@loader(slice)
+def _load_slice(rec, context):
+    return slice(rec['start'], rec['stop'], rec['step'])
+
+
 @saver(CompositeSubsetState)
 def _save_composite_subset_state(state, context):
     return dict(state1=context.id(state.state1),
