@@ -776,6 +776,7 @@ class SpectrumTool(object):
 
         self.image_viewer = image_viewer
         self.viewer_state = self.image_viewer.state
+        self.image_viewer.window_closed.connect(self.close)
 
         self._build_main_widget()
 
@@ -797,6 +798,7 @@ class SpectrumTool(object):
             self._mdi_wrapper.close()
         else:
             self.widget.close()
+        self.image_viewer = None
 
     @property
     def enabled(self):
@@ -987,7 +989,10 @@ class SpectrumTool(object):
         self.widget.show()
 
     def hide(self):
-        self.widget.close()
+        if hasattr(self, '_mdi_wrapper'):
+            self._mdi_wrapper.close()
+        else:
+            self.widget.close()
 
     def _get_modes(self, axes):
         return [self.mouse_mode]
