@@ -115,9 +115,25 @@ class DataViewer(ViewerBase, QtWidgets.QMainWindow):
     apply_roi = set_cursor(Qt.WaitCursor)(ViewerBase.apply_roi)
 
     def close(self, warn=True):
-        self._warn_close = warn
-        QtWidgets.QMainWindow.close(self)
-        ViewerBase.close(self)
+
+        if warn and not self._confirm_close():
+            return
+
+        self._warn_close = False
+
+        if getattr(self, '_mdi_wrapper', None) is not None:
+            self._mdi_wrapper.close()
+            self._mdi_wrapper = None
+        else:
+            try:
+                QtWidgets.QMainWindow.close(self)
+            except RuntimeError:
+                # In some cases the above can raise a "wrapped C/C++ object of
+                # type ... has been deleted" error, in which case we can just
+                # ignore and carry on.
+                pass
+            ViewerBase.close(self)
+
         self._warn_close = True
 
     def mdi_wrap(self):
