@@ -1,6 +1,5 @@
 from __future__ import absolute_import, division, print_function
 
-from glue.utils import nonpartial
 from glue.viewers.matplotlib.qt.toolbar import MatplotlibViewerToolbar
 from glue.core.edit_subset_mode import EditSubsetMode
 from glue.core.util import update_ticks
@@ -31,11 +30,11 @@ class HistogramViewer(MatplotlibDataViewer):
 
     def __init__(self, session, parent=None, state=None):
         super(HistogramViewer, self).__init__(session, parent, state=state)
-        self.state.add_callback('x_att', nonpartial(self._update_axes))
-        self.state.add_callback('x_log', nonpartial(self._update_axes))
-        self.state.add_callback('normalize', nonpartial(self._update_axes))
+        self.state.add_callback('x_att', self._update_axes)
+        self.state.add_callback('x_log', self._update_axes)
+        self.state.add_callback('normalize', self._update_axes)
 
-    def _update_axes(self):
+    def _update_axes(self, *args):
 
         if self.state.x_att is not None:
 
@@ -56,16 +55,7 @@ class HistogramViewer(MatplotlibDataViewer):
 
     # TODO: move some of the ROI stuff to state class?
 
-    def apply_roi(self, roi):
-        if len(self.layers) > 0:
-            cmd = command.ApplyROI(data_collection=self._data,
-                                   roi=roi, apply_func=self._apply_roi)
-            self._session.command_stack.do(cmd)
-        else:
-            # Make sure we force a redraw to get rid of the ROI
-            self.axes.figure.canvas.draw()
-
-    def _apply_roi(self, roi):
+    def _roi_to_subset_state(self, roi):
 
         # TODO Does subset get applied to all data or just visible data?
 
@@ -83,11 +73,7 @@ class HistogramViewer(MatplotlibDataViewer):
 
         x_comp = self.state.x_att.parent.get_component(self.state.x_att)
 
-        subset_state = x_comp.subset_from_roi(self.state.x_att, roi_new,
-                                              coord='x')
-
-        mode = EditSubsetMode()
-        mode.update(self._data, subset_state)
+        return x_comp.subset_from_roi(self.state.x_att, roi_new, coord='x')
 
     @staticmethod
     def update_viewer_state(rec, context):
