@@ -293,6 +293,12 @@ class TestHistogramViewer(object):
 
         assert_equal(state.roi.categories, ['a', 'b'])
 
+    def test_apply_roi_empty(self):
+        # Make sure that doing an ROI selection on an empty viewer doesn't
+        # produce error messsages
+        roi = XRangeROI(-0.2, 0.1)
+        self.viewer.apply_roi(roi)
+
     def test_axes_labels(self):
 
         viewer_state = self.viewer.state
@@ -471,7 +477,7 @@ class TestHistogramViewer(object):
         assert viewer3.state.x_att is dc[0].id['a']
         assert_allclose(viewer3.state.x_min, 0)
         assert_allclose(viewer3.state.x_max, 9)
-        assert_allclose(viewer3.state.y_min, 0.037037037037037035)
+        assert_allclose(viewer3.state.y_min, 0.01111111111111111)
         assert_allclose(viewer3.state.y_max, 0.7407407407407407)
         assert_allclose(viewer3.state.hist_x_min, 0)
         assert_allclose(viewer3.state.hist_x_max, 9)
