@@ -131,7 +131,8 @@ class ImageLayerArtist(BaseImageLayerArtist):
 
     def remove(self):
         super(ImageLayerArtist, self).remove()
-        self.composite.deallocate(self.uuid)
+        if self.uuid in self.composite:
+            self.composite.deallocate(self.uuid)
 
     def get_image_shape(self):
 
@@ -250,31 +251,50 @@ class ImageLayerArtist(BaseImageLayerArtist):
 class ImageSubsetArray(object):
 
     def __init__(self, viewer_state, layer_artist):
-        self.viewer_state = weakref.proxy(viewer_state)
-        self.layer_artist = weakref.proxy(layer_artist)
-        self.layer_state = weakref.proxy(layer_artist.state)
+        self._viewer_state = weakref.ref(viewer_state)
+        self._layer_artist = weakref.ref(layer_artist)
+        self._layer_state = weakref.ref(layer_artist.state)
+
+    @property
+    def layer_artist(self):
+        return self._layer_artist()
+
+    @property
+    def layer_state(self):
+        return self._layer_state()
+
+    @property
+    def viewer_state(self):
+        return self._viewer_state()
 
     @property
     def shape(self):
+
+        if not self.layer_artist._compatible_with_reference_data:
+            return None
+
         x_axis = self.viewer_state.x_att.axis
         y_axis = self.viewer_state.y_att.axis
-        full_shape = self.layer_state.layer.shape
-        return full_shape[y_axis], full_shape[x_axis]
 
-    @property
-    def nan_array(self):
-        return np.ones(self.shape) * np.nan
+        full_shape = self.layer_state.layer.shape
+
+        return full_shape[y_axis], full_shape[x_axis]
 
     def __getitem__(self, view=None):
 
+        if (self.layer_artist is None or
+                self.layer_state is None or
+                self.viewer_state is None):
+            return None
+
         if not self.layer_artist._compatible_with_reference_data:
-            return self.nan_array
+            return None
 
         try:
             mask = self.layer_state.get_sliced_data(view=view)
         except IncompatibleAttribute:
             self.layer_artist.disable_incompatible_subset()
-            return self.nan_array
+            return None
         else:
             self.layer_artist.enable()
 
