@@ -66,8 +66,8 @@ class ImageViewer(MatplotlibDataViewer):
                                             origin='lower', interpolation='nearest')
         self._set_wcs()
 
-    def close(self, **kwargs):
-        super(ImageViewer, self).close(**kwargs)
+    def closeEvent(self, *args):
+        super(ImageViewer, self).closeEvent(*args)
         if self.axes._composite_image is not None:
             self.axes._composite_image.remove()
             self.axes._composite_image = None
@@ -91,24 +91,7 @@ class ImageViewer(MatplotlibDataViewer):
         return result
 
     def _on_slice_change(self, event=None):
-
-        if self.state.x_att is None or self.state.y_att is None or self.state.reference_data is None:
-            return
-
-        coords = self.state.reference_data.coords
-        ix = self.state.x_att.axis
-        iy = self.state.y_att.axis
-        x_dep = list(coords.dependent_axes(ix))
-        y_dep = list(coords.dependent_axes(iy))
-        if ix in x_dep:
-            x_dep.remove(ix)
-        if iy in x_dep:
-            x_dep.remove(iy)
-        if ix in y_dep:
-            y_dep.remove(ix)
-        if iy in y_dep:
-            y_dep.remove(iy)
-        if x_dep or y_dep:
+        if self._changing_slice_requires_wcs_update:
             self._set_wcs(event=event, relim=False)
 
     def _set_wcs(self, event=None, relim=True):
@@ -131,18 +114,34 @@ class ImageViewer(MatplotlibDataViewer):
         if relim:
             self.state.reset_limits()
 
+        # Determine whether changing slices requires changing the WCS
+        ix = self.state.x_att.axis
+        iy = self.state.y_att.axis
+        x_dep = list(ref_coords.dependent_axes(ix))
+        y_dep = list(ref_coords.dependent_axes(iy))
+        if ix in x_dep:
+            x_dep.remove(ix)
+        if iy in x_dep:
+            x_dep.remove(iy)
+        if ix in y_dep:
+            y_dep.remove(ix)
+        if iy in y_dep:
+            y_dep.remove(iy)
+        self._changing_slice_requires_wcs_update = bool(x_dep or y_dep)
+
     # TODO: move some of the ROI stuff to state class?
 
     def apply_roi(self, roi):
         if len(self.layers) > 0:
-            cmd = command.ApplyROI(data_collection=self._data,
-                                   roi=roi, apply_func=self._apply_roi)
+            subset_state = self._roi_to_subset_state(roi)
+            cmd = command.ApplySubsetState(data_collection=self._data,
+                                           subset_state=subset_state)
             self._session.command_stack.do(cmd)
         else:
             # Make sure we force a redraw to get rid of the ROI
             self.axes.figure.canvas.draw()
 
-    def _apply_roi(self, roi):
+    def _roi_to_subset_state(self, roi):
 
         if self.state.x_att is None or self.state.y_att is None or self.state.reference_data is None:
             return
@@ -152,13 +151,10 @@ class ImageViewer(MatplotlibDataViewer):
         x_comp = self.state.x_att.parent.get_component(self.state.x_att)
         y_comp = self.state.y_att.parent.get_component(self.state.y_att)
 
-        subset_state = x_comp.subset_from_roi(self.state.x_att, roi,
-                                              other_comp=y_comp,
-                                              other_att=self.state.y_att,
-                                              coord='x')
-
-        mode = EditSubsetMode()
-        mode.update(self._data, subset_state)
+        return x_comp.subset_from_roi(self.state.x_att, roi,
+                                      other_comp=y_comp,
+                                      other_att=self.state.y_att,
+                                      coord='x')
 
     def _scatter_artist(self, axes, state, layer=None, layer_state=None):
         if len(self._layer_artist_container) == 0:
