@@ -24,7 +24,7 @@ from glue.viewers.matplotlib.qt.tests.test_data_viewer import BaseTestMatplotlib
 from glue.core.state import GlueUnSerializer
 from glue.app.qt.layer_tree_widget import LayerTreeWidget
 from glue.viewers.scatter.state import ScatterLayerState
-from glue.viewers.image.state import ImageLayerState, ImageSubsetLayerState
+from glue.viewers.image.state import ImageLayerState, ImageSubsetLayerState, AggregateSlice
 from glue.core.link_helpers import LinkSame
 from glue.app.qt import GlueApplication
 
@@ -36,7 +36,7 @@ DATA = os.path.join(os.path.dirname(__file__), 'data')
 class TestImageCommon(BaseTestMatplotlibDataViewer):
 
     def init_data(self):
-        return Data(label='d1', x=np.arange(12).reshape((3, 4)), y=np.ones((3, 4)))
+        return Data(label='d1', x=np.arange(24).reshape((2, 3, 4)), y=np.ones((2, 3, 4)))
 
     viewer_cls = ImageViewer
 
@@ -81,7 +81,7 @@ class TestImageViewer(object):
         self.data_collection.append(self.image1_wcs)
         self.data_collection.append(self.hypercube_wcs)
 
-        self.viewer = ImageViewer(self.session)
+        self.viewer = self.application.new_data_viewer(ImageViewer)
 
         self.data_collection.register_to_hub(self.hub)
         self.viewer.register_to_hub(self.hub)
@@ -580,6 +580,56 @@ class TestImageViewer(object):
         assert not self.viewer.layers[2].enabled  # image subset
         assert self.viewer.layers[3].enabled  # scatter subset
 
+    def test_save_aggregate_slice(self, tmpdir):
+
+        # Regression test to make sure that image viewers that include
+        # aggregate slice objects in the slices can be saved/restored
+
+        self.viewer.add_data(self.hypercube)
+        self.viewer.state.slices = AggregateSlice(slice(1, 3), 10, np.sum), 3, 0, 0
+
+        filename = tmpdir.join('session.glu').strpath
+
+        self.application.save_session(filename)
+        self.application.close()
+
+        app2 = GlueApplication.restore_session(filename)
+        viewer_state = app2.viewers[0][0].state
+        slices = viewer_state.slices
+        assert isinstance(slices[0], AggregateSlice)
+        assert slices[0].slice == slice(1, 3)
+        assert slices[0].center == 10
+        assert slices[0].function is np.sum
+        assert slices[1:] == (3, 0, 0)
+
+        app2.close()
+
+    def test_subset_cube_image(self):
+
+        # Regression test to make sure that if an image and cube are present
+        # in an image viewer and a subset is also present, we don't get an
+        # error when trying to access the subset shape
+
+        self.viewer.add_data(self.image1)
+        self.data_collection.new_subset_group(label='subset',
+                                              subset_state=self.image1.id['x'] > 1.5)
+
+        self.viewer.add_data(self.hypercube)
+        self.viewer.state.reference_data = self.hypercube
+
+        assert self.viewer.layers[1].subset_array.shape is None
+        assert self.viewer.layers[3].subset_array.shape == (4, 5)
+
+    def test_preserve_slice(self):
+
+        # Regression test to make sure that when adding a second dataset to
+        # an image viewer, the current slice in a cube does not change.
+
+        self.viewer.add_data(self.hypercube)
+        self.viewer.state.slices = (1, 2, 3, 4)
+        self.viewer.add_data(self.image1)
+        assert self.viewer.state.slices == (1, 2, 3, 4)
+
 
 class TestSessions(object):
 
