@@ -4,10 +4,18 @@ from __future__ import absolute_import, division, print_function
 
 import pytest
 
+try:
+    import objgraph
+except ImportError:
+    OBJGRAPH_INSTALLED = False
+else:
+    OBJGRAPH_INSTALLED = True
+
 from glue.core import Data
 from glue.core.exceptions import IncompatibleDataException
 from glue.app.qt.application import GlueApplication
 from glue.core.roi import XRangeROI
+from glue.utils.qt import get_qapp
 
 
 class MatplotlibDrawCounter(object):
@@ -39,6 +47,9 @@ class BaseTestMatplotlibDataViewer(object):
 
     def setup_method(self, method):
 
+        if OBJGRAPH_INSTALLED:
+            self.viewer_count_start = self.viewer_count
+
         self.data = self.init_data()
 
         self.application = GlueApplication()
@@ -57,8 +68,30 @@ class BaseTestMatplotlibDataViewer(object):
         cid = self.data.visible_components[0]
         self.data_collection.new_subset_group('subset 1', cid > 0)
 
+    @property
+    def viewer_count(self):
+        app = get_qapp()
+        app.processEvents()
+        obj = objgraph.by_type(self.viewer_cls.__name__)
+        return len(obj)
+
     def teardown_method(self, method):
-        self.viewer.close()
+
+        if self.viewer is not None:
+            self.viewer.close()
+        self.application.close()
+
+        # The following is a check to make sure that once the viewer and
+        # application have been closed, there are no leftover references to
+        # the data viewer. This was introduced because there were previously
+        # circular references that meant that viewer instances were not
+        # properly garbage collected, which in turn meant they still reacted
+        # in some cases to events.
+        if OBJGRAPH_INSTALLED:
+            self.viewer = None
+            self.application = None
+            if self.viewer_count > self.viewer_count_start:
+                raise ValueError("No net viewers should be created in tests")
 
     def test_add_data(self):
 
@@ -492,3 +525,15 @@ class BaseTestMatplotlibDataViewer(object):
 
         assert self.data.subsets[0].subset_state.lo == lo2
         assert self.data.subsets[0].subset_state.hi == hi2
+
+    def test_numerical_data_changed(self):
+        self.init_draw_count()
+        self.init_subset()
+        assert self.draw_count == 0
+        self.viewer.add_data(self.data)
+        assert self.draw_count == 1
+        data = Data()
+        for cid in self.data.visible_components:
+            data.add_component(self.data[cid] * 2, cid.label)
+        self.data.update_values_from_data(data)
+        assert self.draw_count == 2
